@@ -192,7 +192,7 @@ class Ui_MainWindow(object):
     def savePage(self):
         s=str(self.page)
 
-	f = open('quran_track.ptr', "w")
+	f = open('/usr/lib/quran/quran_track.ptr', "w")
         f.write(s)
         f.close()
         QtGui.QMessageBox.information(None, 'Save','This page is already saved', QtGui.QMessageBox.Close)
@@ -200,7 +200,7 @@ class Ui_MainWindow(object):
 
 
     def loadPage(self):
-        f = QtCore.QFile('quran_track.ptr')
+        f = QtCore.QFile('/usr/lib/quran/quran_track.ptr')
         f.open(QtCore.QIODevice.ReadOnly)
         strpage=QtCore.QTextStream(f).readLine()
         self.page=int(strpage)
